@@ -33,8 +33,8 @@
 #
 ##-----------------------------------------------------------------------------
 hardTh <- function(y, thld) {
-    x = (abs(y) > thld) * y;
+    x = (abs(y) > thld) * y
 
-    return(x);
+    return(x)
 }
 
