@@ -4,18 +4,16 @@
 
 library(rwt)
 
-test.mdwt <- function(signal, filter, nlevels, expected) {
-   result <- mdwt(signal, filter, nlevels);
+test.mdwt <- function(input, expected) {
+   result <- rwt::mdwt(input$signal, input$filter, input$nlevels)
    identical(all.equal(result,
                        expected,
                        tolerance = 0.000001),
-             TRUE);
+             TRUE)
 }
 
-sig <- makesig(SIGNAL.LIN.CHIRP, 8);
-h <- daubcqf(4, PHASE.MINIMUM);
-L <- 2;
-
+sig <- rwt::makesig(SIGNAL.LIN.CHIRP, 8)
+h <- rwt::daubcqf(4, PHASE.MINIMUM)
 mdwt.expected <- list(y = matrix(data = c( 1.109692,
                                            0.8766618,
                                            0.8203919,
@@ -25,7 +23,7 @@ mdwt.expected <- list(y = matrix(data = c( 1.109692,
                                            0.2200882,
                                           -0.1400816),
                                  nrow = 1),
-                      L = 2);
+                      L = 2)
 
-test.mdwt(sig$x, h$h.0, L, mdwt.expected);
+test.mdwt(list(signal = sig$x, filter = h$h.0, nlevels = 2), mdwt.expected)
 
