@@ -4,16 +4,15 @@
 
 library(rwt)
 
-test.softTh <- function(signal, thld, expected) {
-   result <- rwt::softTh(signal, thld);
+test.softTh <- function(input, expected) {
+   result <- rwt::softTh(input$signal, input$thld)
    identical(all.equal(as.vector(result),
                        expected,
                        tolerance = 0.000001),
-             TRUE);
+             TRUE)
 }
 
-sig <- makesig(SIGNAL.DOPPLER, 8);
-thld <- 0.2;
+sig <- rwt::makesig(SIGNAL.DOPPLER, 8)
 softTh.expected <- c( 0.0,
                       0.0,
                       0.0,
@@ -21,7 +20,7 @@ softTh.expected <- c( 0.0,
                       0.0,
                       0.2000516,
                       0.04826153,
-                      0.0);
+                      0.0)
 
-test.softTh(sig$x, thld, softTh.expected);
+test.softTh(list(signal = sig$x, thld = 0.2), softTh.expected)
 
